<?php
session_start();
// Thư mục lưu ảnh đã upload
$baseUploadDir = 'upload/';

// Tạo thư mục mới cho mỗi lần upload theo tên tùy chỉnh từ người dùng
if (isset($_GET['customDir']) && !empty($_GET['customDir'])) {
    $customDirName = preg_replace('/[^a-zA-Z0-9_-]/', '_', $_GET['customDir']); // Loại bỏ ký tự không hợp lệ
    $currentUploadDir = $baseUploadDir . $customDirName . '/';
} else {
    $currentUploadDir = $baseUploadDir . date('Y-m-d_H-i-s') . '/';
}

if (!is_dir($currentUploadDir)) {
    mkdir($currentUploadDir, 0777, true);
}

// Lấy danh sách file đã upload
$uploadedFiles = isset($_SESSION['uploaded_files']) && is_array($_SESSION['uploaded_files']) ? $_SESSION['uploaded_files'] : [];
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Upload Image</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            margin: 20px;
        }
        .progress {
            width: 100%;
            background: #f3f3f3;
            border: 1px solid #ccc;
            border-radius: 5px;
            overflow: hidden;
            margin-bottom: 10px;
        }
        .progress-bar {
            height: 20px;
            background: #4caf50;
            width: 0;
            text-align: center;
            color: white;
            line-height: 20px;
        }
        table {
            width: 100%;
            border-collapse: collapse;
            margin-top: 20px;
        }
        table, th, td {
            border: 1px solid #ddd;
        }
        th, td {
            padding: 8px;
            text-align: left;
        }
        th {
            background: #f4f4f4;
        }
        .copy-btn {
            cursor: pointer;
            color: blue;
            text-decoration: underline;
        }
        img {
            width: 150px;
            height: auto;
        }
    </style>
</head>
<body>

<h1>Upload Image</h1>

<form id="uploadForm" enctype="multipart/form-data">
    <input type="text" name="customDir" id="customDirInput" placeholder="Enter folder name" required>
    <input type="file" name="files[]" id="fileInput" multiple required>
    <button type="submit">Upload</button>
</form>

<div class="progress" id="progressContainer">
    <div class="progress-bar" id="progressBar">0%</div>
</div>

<table>
    <thead>
        <tr>
            <th>Image</th>
            <th>File Name</th>
            <th>File Path</th>
        </tr>
    </thead>
    <tbody id="fileList">
        <?php foreach ($uploadedFiles as $file): ?>
            <?php if (is_array($file) && isset($file['path'], $file['name'])): ?>
                <tr>
                    <td><img src="<?php echo 'https://vnimpressivetours.fr/upimage/upload/' . $file['path']; ?>" alt=""></td>
                    <td><?php echo htmlspecialchars($file['name']); ?></td>
                    <td>
                        <input type="text" value="<?php echo 'https://vnimpressivetours.fr/upimage/upload/' . $file['path']; ?>" readonly>
                        <span class="copy-btn" onclick="copyToClipboard(this)">Copy</span>
                    </td>
                </tr>
            <?php endif; ?>
        <?php endforeach; ?>
    </tbody>
</table>

<script>
// Tải ảnh
const form = document.getElementById('uploadForm');
const progressBar = document.getElementById('progressBar');
const progressContainer = document.getElementById('progressContainer');
const fileList = document.getElementById('fileList');

form.addEventListener('submit', function (e) {
    e.preventDefault();

    const fileInput = document.getElementById('fileInput');
    const customDirInput = document.getElementById('customDirInput');
    const files = fileInput.files;
    if (files.length === 0 || customDirInput.value.trim() === '') return;

    const formData = new FormData();
    formData.append('customDir', customDirInput.value);
    for (let i = 0; i < files.length; i++) {
        formData.append('files[]', files[i]);
    }

    const xhr = new XMLHttpRequest();
    xhr.open('POST', 'upload_handler.php', true);

    xhr.upload.onprogress = function (e) {
        if (e.lengthComputable) {
            const percentComplete = (e.loaded / e.total) * 100;
            progressBar.style.width = percentComplete + '%';
            progressBar.textContent = Math.round(percentComplete) + '%';
        }
    };

    xhr.onload = function () {
        try {
            const response = JSON.parse(xhr.responseText);
            if (response.success) {
                response.files.forEach(file => {
                    const newRow = document.createElement('tr');
                    newRow.innerHTML = `
                        <td><img src="https://vnimpressivetours.fr/upimage/upload/${file.path}" alt=""></td>
                        <td>${file.name}</td>
                        <td>
                            <input type="text" value="https://vnimpressivetours.fr/upimage/upload/${file.path}" readonly>
                            <span class="copy-btn" onclick="copyToClipboard(this)">Copy</span>
                        </td>
                    `;
                    fileList.appendChild(newRow);
                });
                fileInput.value = '';
                customDirInput.value = '';
                progressBar.style.width = '0';
                progressBar.textContent = '0%';
            } else {
                alert(response.messages.join('\n'));
            }
        } catch (e) {
            alert('Invalid server response: ' + xhr.responseText);
        }
    };

    xhr.send(formData);
});

// Sao chép đường dẫn
function copyToClipboard(button) {
    const input = button.previousElementSibling;
    input.select();
    input.setSelectionRange(0, 99999);
    navigator.clipboard.writeText(input.value).then(() => {
        alert('Copied to clipboard!');
    });
}
</script>

</body>
</html>
